==> maven_3.5.4.orig.tar.xz: maven-maven-3.5.4/maven-compat/src/test/java/org/apache/maven/repository/DefaultMirrorSelectorTest.java <==
package org.apache.maven.repository;

/*
 * Licensed to the Apache Software Foundation (ASF) under one
 * or more contributor license agreements.  See the NOTICE file
 * distributed with this work for additional information
 * regarding copyright ownership.  The ASF licenses this file
 * to you under the Apache License, Version 2.0 (the
 * "License"); you may not use this file except in compliance
 * with the License.  You may obtain a copy of the License at
 *
 *  http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing,
 * software distributed under the License is distributed on an
 * "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY
 * KIND, either express or implied.  See the License for the
 * specific language governing permissions and limitations
 * under the License.
 */

import org.apache.maven.artifact.repository.ArtifactRepository;
import org.apache.maven.artifact.repository.DefaultArtifactRepository;
import org.codehaus.plexus.PlexusTestCase;

public class DefaultMirrorSelectorTest
    extends PlexusTestCase
{

    public void testMirrorWithMirrorOfPatternContainingANegationIsNotSelected()
    {
        ArtifactRepository repository = new DefaultArtifactRepository( "snapshots.repo", "http://whatever", null );
        String pattern = "external:*, !snapshots.repo";
        boolean matches = DefaultMirrorSelector.matchPattern( repository, pattern );
        System.out.println( matches );
        assertFalse( matches );
    }
}

==> maven_3.9.9.orig.tar.xz: maven-maven-3.9.9/maven-compat/src/test/java/org/apache/maven/repository/DefaultMirrorSelectorTest.java <==
/*
 * Licensed to the Apache Software Foundation (ASF) under one
 * or more contributor license agreements.  See the NOTICE file
 * distributed with this work for additional information
 * regarding copyright ownership.  The ASF licenses this file
 * to you under the Apache License, Version 2.0 (the
 * "License"); you may not use this file except in compliance
 * with the License.  You may obtain a copy of the License at
 *
 *   http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing,
 * software distributed under the License is distributed on an
 * "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY
 * KIND, either express or implied.  See the License for the
 * specific language governing permissions and limitations
 * under the License.
 */
package org.apache.maven.repository;

import org.apache.maven.artifact.repository.ArtifactRepository;
import org.apache.maven.artifact.repository.DefaultArtifactRepository;
import org.codehaus.plexus.PlexusTestCase;

public class DefaultMirrorSelectorTest extends PlexusTestCase {

    public void testMirrorWithMirrorOfPatternContainingANegationIsNotSelected() {
        ArtifactRepository repository = new DefaultArtifactRepository("snapshots.repo", "http://whatever", null);
        String pattern = "external:*, !snapshots.repo";
        boolean matches = DefaultMirrorSelector.matchPattern(repository, pattern);
        System.out.println(matches);
        assertFalse(matches);
    }
}
